Clarabel solver main module.
This module contains the main types and traits for the Clarabel solver.
The solver comes with a default implementation of all required traits. This produces a solver that solves problems in the standard format described in the top level API page and the User’s guide. This implementation is the most appropriate choice for nearly all users.
It is also possible to implement a custom solver by defining a collection of custom types that together implement all of the required core traits for objects in Clarabel’s core solver.
Re-exports
pub use crate::solver::implementations::default;pub use crate::solver::core::cones::SupportedConeT::*;pub use crate::solver::implementations::default::*;
Modules
- ffi
- FFI friendly versions of internal solver types
- implementations
- Concrete implementations for specific problem formats.
- traits
- Required traits for types providing a Clarabel solver implementation.
Structs
- Linear
Solver Info - Linear subsolver information.
Enums
- Solver
Status - Status of solver at termination
- Supported
ConeT - API type describing the type of a conic constraint.
Traits
- IPSolver
- An interior point solver implementing a predictor-corrector scheme
- SolverJSON
Read Write - JSON file read/write trait for solver data. Only available with the “serde” feature enabled.
Type Aliases
- Core
Settings - Solver general core settings are the same as in the default solver.